@@ -50,14 +50,13 @@ class AMQPIncomingMessage(base.RpcIncomingMessage):
         self.stopwatch = timeutils.StopWatch()
         self.stopwatch.start()
 
-    def _send_reply(self, conn, reply=None, failure=None, log_failure=True):
+    def _send_reply(self, conn, reply=None, failure=None):
         if not self._obsolete_reply_queues.reply_q_valid(self.reply_q,
                                                          self.msg_id):
             return
 
         if failure:
-            failure = rpc_common.serialize_remote_exception(failure,
-                                                            log_failure)
+            failure = rpc_common.serialize_remote_exception(failure)
         # NOTE(sileht): ending can be removed in N*, see Listener.wait()
         # for more detail.
         msg = {'result': reply, 'failure': failure, 'ending': True,
@@ -74,7 +73,7 @@ class AMQPIncomingMessage(base.RpcIncomingMessage):
                       'elapsed': self.stopwatch.elapsed()})
         conn.direct_send(self.reply_q, rpc_common.serialize_msg(msg))
 
-    def reply(self, reply=None, failure=None, log_failure=True):
+    def reply(self, reply=None, failure=None):
         if not self.msg_id:
             # NOTE(Alexei_987) not sending reply, if msg_id is empty
             #    because reply should not be expected by caller side
@@ -96,8 +95,7 @@ class AMQPIncomingMessage(base.RpcIncomingMessage):
             try:
                 with self.listener.driver._get_connection(
                         rpc_common.PURPOSE_SEND) as conn:
-                    self._send_reply(conn, reply, failure,
-                                     log_failure=log_failure)
+                    self._send_reply(conn, reply, failure)
                 return
             except rpc_amqp.AMQPDestinationNotFound:
                 if timer.check_return() > 0:
@@ -176,7 +174,7 @@ class ObsoleteReplyQueuesCache(object):
                                         'msg_id': msg_id})
 
 
-class AMQPListener(base.Listener):
+class AMQPListener(base.PollStyleListener):
 
     def __init__(self, driver, conn):
         super(AMQPListener, self).__init__(driver.prefetch_size)
@@ -189,17 +187,13 @@ class AMQPListener(base.Listener):
 
     def __call__(self, message):
         ctxt = rpc_amqp.unpack_context(message)
-
-        # FIXME(sileht): Don't log the message until strutils is more
-        # efficient, (rpc_amqp.unpack_context already log the context)
-        # LOG.debug(u'received: %s',
-        #           strutils.mask_password(six.text_type(dict(message))))
-
         unique_id = self.msg_id_cache.check_duplicate_message(message)
-
-        LOG.debug("received message msg_id: %(msg_id)s reply to %(queue)s", {
-            'queue': ctxt.reply_q, 'msg_id': ctxt.msg_id})
-
+        if ctxt.msg_id:
+            LOG.debug("received message msg_id: %(msg_id)s reply to "
+                      "%(queue)s", {'queue': ctxt.reply_q,
+                                    'msg_id': ctxt.msg_id})
+        else:
+            LOG.debug("received message with unique_id: %s", unique_id)
         self.incoming.append(AMQPIncomingMessage(self,
                                                  ctxt.to_dict(),
                                                  message,
@@ -473,7 +467,7 @@ class AMQPDriverBase(base.BaseDriver):
         return self._send(target, ctxt, message,
                           envelope=(version == 2.0), notify=True, retry=retry)
 
-    def listen(self, target):
+    def listen(self, target, batch_size, batch_timeout):
         conn = self._get_connection(rpc_common.PURPOSE_LISTEN)
 
         listener = AMQPListener(self, conn)
@@ -487,9 +481,11 @@ class AMQPDriverBase(base.BaseDriver):
                                     callback=listener)
         conn.declare_fanout_consumer(target.topic, listener)
 
-        return listener
+        return base.PollStyleListenerAdapter(listener, batch_size,
+                                             batch_timeout)
 
-    def listen_for_notifications(self, targets_and_priorities, pool):
+    def listen_for_notifications(self, targets_and_priorities, pool,
+                                 batch_size, batch_timeout):
         conn = self._get_connection(rpc_common.PURPOSE_LISTEN)
 
         listener = AMQPListener(self, conn)
@@ -498,7 +494,8 @@ class AMQPDriverBase(base.BaseDriver):
                 exchange_name=self._get_exchange(target),
                 topic='%s.%s' % (target.topic, priority),
                 callback=listener, queue_name=pool)
-        return listener
+        return base.PollStyleListenerAdapter(listener, batch_size,
+                                             batch_timeout)
 
     def cleanup(self):
         if self._connection_pool:
