@@ -15,13 +15,10 @@
 
 from oslo_messaging._drivers import common
 from oslo_messaging._drivers.zmq_driver.client.publishers.dealer \
-    import zmq_dealer_call_publisher
-from oslo_messaging._drivers.zmq_driver.client.publishers.dealer \
-    import zmq_dealer_publisher
+    import zmq_dealer_publisher_direct
 from oslo_messaging._drivers.zmq_driver.client.publishers.dealer \
     import zmq_dealer_publisher_proxy
-from oslo_messaging._drivers.zmq_driver.client.publishers \
-    import zmq_publisher_base
+from oslo_messaging._drivers.zmq_driver.client import zmq_ack_manager
 from oslo_messaging._drivers.zmq_driver.client import zmq_client_base
 from oslo_messaging._drivers.zmq_driver import zmq_async
 from oslo_messaging._drivers.zmq_driver import zmq_names
@@ -43,28 +40,28 @@ class ZmqClientMixDirectPubSub(zmq_client_base.ZmqClientBase):
 
     def __init__(self, conf, matchmaker=None, allowed_remote_exmods=None):
 
-        if conf.use_router_proxy or not conf.use_pub_sub:
+        if conf.oslo_messaging_zmq.use_router_proxy or not \
+                conf.oslo_messaging_zmq.use_pub_sub:
             raise WrongClientException()
 
-        self.sockets_manager = zmq_publisher_base.SocketsManager(
-            conf, matchmaker, zmq.ROUTER, zmq.DEALER)
+        publisher_direct = self.create_publisher(
+            conf, matchmaker,
+            zmq_dealer_publisher_direct.DealerPublisherDirect,
+            zmq_ack_manager.AckManagerDirect
+        )
 
-        fanout_publisher = zmq_dealer_publisher_proxy.DealerPublisherProxy(
-            conf, matchmaker, self.sockets_manager.get_socket_to_publishers())
+        publisher_proxy = self.create_publisher(
+            conf, matchmaker,
+            zmq_dealer_publisher_proxy.DealerPublisherProxy,
+            zmq_ack_manager.AckManagerProxy
+        )
 
         super(ZmqClientMixDirectPubSub, self).__init__(
             conf, matchmaker, allowed_remote_exmods,
             publishers={
-                zmq_names.CALL_TYPE:
-                    zmq_dealer_call_publisher.DealerCallPublisher(
-                        conf, matchmaker, self.sockets_manager),
-
-                zmq_names.CAST_FANOUT_TYPE: fanout_publisher,
-
-                zmq_names.NOTIFY_TYPE: fanout_publisher,
-
-                "default": zmq_dealer_publisher.DealerPublisherAsync(
-                    conf, matchmaker)
+                zmq_names.CAST_FANOUT_TYPE: publisher_proxy,
+                zmq_names.NOTIFY_TYPE: publisher_proxy,
+                "default": publisher_direct
             }
         )
 
@@ -79,22 +76,19 @@ class ZmqClientDirect(zmq_client_base.ZmqClientBase):
 
     def __init__(self, conf, matchmaker=None, allowed_remote_exmods=None):
 
-        if conf.use_pub_sub or conf.use_router_proxy:
+        if conf.oslo_messaging_zmq.use_pub_sub or \
+                conf.oslo_messaging_zmq.use_router_proxy:
             raise WrongClientException()
 
-        self.sockets_manager = zmq_publisher_base.SocketsManager(
-            conf, matchmaker, zmq.ROUTER, zmq.DEALER)
+        publisher = self.create_publisher(
+            conf, matchmaker,
+            zmq_dealer_publisher_direct.DealerPublisherDirect,
+            zmq_ack_manager.AckManagerDirect
+        )
 
         super(ZmqClientDirect, self).__init__(
             conf, matchmaker, allowed_remote_exmods,
-            publishers={
-                zmq_names.CALL_TYPE:
-                    zmq_dealer_call_publisher.DealerCallPublisher(
-                        conf, matchmaker, self.sockets_manager),
-
-                "default": zmq_dealer_publisher.DealerPublisher(
-                    conf, matchmaker)
-            }
+            publishers={"default": publisher}
         )
 
 
@@ -110,21 +104,16 @@ class ZmqClientProxy(zmq_client_base.ZmqClientBase):
 
     def __init__(self, conf, matchmaker=None, allowed_remote_exmods=None):
 
-        if not conf.use_router_proxy:
+        if not conf.oslo_messaging_zmq.use_router_proxy:
             raise WrongClientException()
 
-        self.sockets_manager = zmq_publisher_base.SocketsManager(
-            conf, matchmaker, zmq.ROUTER, zmq.DEALER)
+        publisher = self.create_publisher(
+            conf, matchmaker,
+            zmq_dealer_publisher_proxy.DealerPublisherProxy,
+            zmq_ack_manager.AckManagerProxy
+        )
 
         super(ZmqClientProxy, self).__init__(
             conf, matchmaker, allowed_remote_exmods,
-            publishers={
-                zmq_names.CALL_TYPE:
-                    zmq_dealer_publisher_proxy.DealerCallPublisherProxy(
-                        conf, matchmaker, self.sockets_manager),
-
-                "default": zmq_dealer_publisher_proxy.DealerPublisherProxy(
-                        conf, matchmaker,
-                        self.sockets_manager.get_socket_to_publishers())
-            }
+            publishers={"default": publisher}
         )
