@@ -23,6 +23,7 @@ __all__ = [
     'ServerListenError',
 ]
 
+import abc
 import functools
 import inspect
 import logging
@@ -32,12 +33,12 @@ import traceback
 from oslo_config import cfg
 from oslo_service import service
 from oslo_utils import eventletutils
-from oslo_utils import excutils
 from oslo_utils import timeutils
+import six
 from stevedore import driver
 
 from oslo_messaging._drivers import base as driver_base
-from oslo_messaging._i18n import _LW
+from oslo_messaging._i18n import _LW, _LI
 from oslo_messaging import exceptions
 
 LOG = logging.getLogger(__name__)
@@ -295,6 +296,7 @@ def ordered(after=None, reset_after=None):
     return _ordered
 
 
+@six.add_metaclass(abc.ABCMeta)
 class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
     """Server for handling messages.
 
@@ -306,17 +308,19 @@ class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
     def __init__(self, transport, dispatcher, executor='blocking'):
         """Construct a message handling server.
 
-        The dispatcher parameter is a callable which is invoked with context
-        and message dictionaries each time a message is received.
+        The dispatcher parameter is a DispatcherBase instance which is used
+        for routing request to endpoint for processing.
 
         The executor parameter controls how incoming messages will be received
         and dispatched. By default, the most simple executor is used - the
-        blocking executor.
+        blocking executor. It handles only one message at once. It's
+        recommended to use threading or eventlet.
 
         :param transport: the messaging transport
         :type transport: Transport
-        :param dispatcher: a callable which is invoked for each method
-        :type dispatcher: callable
+        :param dispatcher: has a dispatch() method which is invoked for each
+                           incoming request
+        :type dispatcher: DispatcherBase
         :param executor: name of message executor - for example
                          'eventlet', 'blocking'
         :type executor: str
@@ -327,6 +331,14 @@ class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
         self.transport = transport
         self.dispatcher = dispatcher
         self.executor_type = executor
+        if self.executor_type == 'blocking':
+            # NOTE(sileht): We keep blocking as default to not enforce the
+            # application to use threading or eventlet. Because application
+            # have to be preprepared accordingly for each one (monkeypatching,
+            # threadsafe, ...)
+            LOG.info(_LI("blocking executor handles only one message at "
+                         "once. threading or eventlet executor is "
+                         "recommended."))
 
         self.listener = None
 
@@ -339,15 +351,30 @@ class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
         self._executor_cls = mgr.driver
 
         self._work_executor = None
-        self._poll_executor = None
 
         self._started = False
 
         super(MessageHandlingServer, self).__init__()
 
-    def _submit_work(self, callback):
-        fut = self._work_executor.submit(callback.run)
-        fut.add_done_callback(lambda f: callback.done())
+    def _on_incoming(self, incoming):
+        """Handles on_incoming event
+
+        :param incoming: incoming request.
+        """
+        self._work_executor.submit(self._process_incoming, incoming)
+
+    @abc.abstractmethod
+    def _process_incoming(self, incoming):
+        """Perform processing incoming request
+
+        :param incoming: incoming request.
+        """
+
+    @abc.abstractmethod
+    def _create_listener(self):
+        """Creates listener object for polling requests
+        :return: MessageListenerAdapter
+        """
 
     @ordered(reset_after='stop')
     def start(self, override_pool_size=None):
@@ -373,11 +400,6 @@ class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
                             'instantiate a new object.'))
         self._started = True
 
-        try:
-            self.listener = self.dispatcher._listen(self.transport)
-        except driver_base.TransportDriverError as ex:
-            raise ServerListenError(self.target, ex)
-
         executor_opts = {}
 
         if self.executor_type == "threading":
@@ -393,9 +415,13 @@ class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
             )
 
         self._work_executor = self._executor_cls(**executor_opts)
-        self._poll_executor = self._executor_cls(**executor_opts)
 
-        return lambda: self._poll_executor.submit(self._runner)
+        try:
+            self.listener = self._create_listener()
+        except driver_base.TransportDriverError as ex:
+            raise ServerListenError(self.target, ex)
+
+        self.listener.start(self._on_incoming)
 
     @ordered(after='start')
     def stop(self):
@@ -409,28 +435,6 @@ class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
         self.listener.stop()
         self._started = False
 
-    @excutils.forever_retry_uncaught_exceptions
-    def _runner(self):
-        while self._started:
-            incoming = self.listener.poll(
-                timeout=self.dispatcher.batch_timeout,
-                prefetch_size=self.dispatcher.batch_size)
-
-            if incoming:
-                self._submit_work(self.dispatcher(incoming))
-
-        # listener is stopped but we need to process all already consumed
-        # messages
-        while True:
-            incoming = self.listener.poll(
-                timeout=self.dispatcher.batch_timeout,
-                prefetch_size=self.dispatcher.batch_size)
-
-            if incoming:
-                self._submit_work(self.dispatcher(incoming))
-            else:
-                return
-
     @ordered(after='stop')
     def wait(self):
         """Wait for message processing to complete.
@@ -442,7 +446,6 @@ class MessageHandlingServer(service.ServiceBase, _OrderedTaskRunner):
         Once it's finished, the underlying driver resources associated to this
         server are released (like closing useless network connections).
         """
-        self._poll_executor.shutdown(wait=True)
         self._work_executor.shutdown(wait=True)
 
         # Close listener connection after processing all messages
